@@ -1,7 +1,8 @@
 #!/bin/sh
 
-IOSEVKA_VERSION=32.4.0
+IOSEVKA_VERSION=34.1.0
 ARCHIVE=v${IOSEVKA_VERSION}.zip
+HASH=88c8e6bdaf258225902968a2984b38db81c16135b7a1c4b7c8c53dae8bcfa79c
 
 BASE_URL=https://github.com/be5invis/Iosevka/archive/refs/tags/
 
@@ -10,9 +11,16 @@ BUILD_DIR=Iosevka-${IOSEVKA_VERSION}
 cd $(dirname $0)
 set -e
 
+die() {
+  echo "$@" >&2
+  exit 1
+}
+
 download_source() {
   rm --force "${ARCHIVE}"
   wget "${BASE_URL}/${ARCHIVE}"
+  echo "${HASH} ${ARCHIVE}" | \
+    sha256sum --check --status || die "${ARCHIVE} has invalid checksum"
 }
 
 extract_source() {
